Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(688)

Unified Diff: content/browser/frame_host/render_frame_host_manager.h

Issue 1412333002: Revert of Properly recreate swapped out RenderView. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | content/browser/frame_host/render_frame_host_manager.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/browser/frame_host/render_frame_host_manager.h
diff --git a/content/browser/frame_host/render_frame_host_manager.h b/content/browser/frame_host/render_frame_host_manager.h
index 3cf8ea569f51a7a57a08c05024b90c11ad5e261e..3a40ad73e5bc87f71b23a73a81dff4d788ad1f4c 100644
--- a/content/browser/frame_host/render_frame_host_manager.h
+++ b/content/browser/frame_host/render_frame_host_manager.h
@@ -669,12 +669,13 @@
SiteInstance* new_instance,
int bindings);
// Sets up the necessary state for a new RenderViewHost. If |proxy| is not
// null, it creates a RenderFrameProxy in the target renderer process which is
// used to route IPC messages when in swapped out state. Returns early if the
// RenderViewHost has already been initialized for another RenderFrameHost.
bool InitRenderView(RenderViewHostImpl* render_view_host,
- RenderFrameProxyHost* proxy);
+ int proxy_routing_id);
// Initialization for RenderFrameHost uses the same sequence as InitRenderView
// above.
« no previous file with comments | « no previous file | content/browser/frame_host/render_frame_host_manager.cc » ('j') | no next file with comments »
@@ -669,12 +669,13 @@
SiteInstance* new_instance,
int bindings);
- // Sets up the necessary state for a new RenderViewHost. If |proxy| is not
- // null, it creates a RenderFrameProxy in the target renderer process which is
- // used to route IPC messages when in swapped out state. Returns early if the
- // RenderViewHost has already been initialized for another RenderFrameHost.
+ // Sets up the necessary state for a new RenderViewHost. Creates a
+ // RenderFrameProxy in the target renderer process with the given
+ // |proxy_routing_id|, which is used to route IPC messages when in swapped
+ // out state. Returns early if the RenderViewHost has already been
+ // initialized for another RenderFrameHost.
bool InitRenderView(RenderViewHostImpl* render_view_host,

Powered by Google App Engine
This is Rietveld 408576698